shortExampleAntModel: Model syntax for the short example in the 'antcolony.lavaan'...

shortExampleAntModelR Documentation

Model syntax for the short example in the antcolony.lavaan function.

Description

A character vector containing the model syntax used for the one factor, 15-item, example in the antcolony.lavaan.

Usage

data(shortExampleAntModel)

Format

A character vector.


ShortForm documentation built on May 6, 2026, 9:06 a.m.